atanf
产品支持情况
- Ascend 950PR&950DT系列产品:支持
- Atlas A3系列产品:不支持
- Atlas A2系列产品:不支持
- Atlas 200I/500 A2推理产品:不支持
- Atlas推理系列产品AI Core:不支持
- Atlas推理系列产品Vector Core:不支持
- Atlas训练系列产品:不支持
功能说明
头文件路径为:"simt_api/math_functions.h"。
获取输入数据的反正切值。

函数原型
inline float atanf(float x)
参数说明
表1 参数说明
| 参数名 | 输入/输出 | 描述 |
|---|---|---|
| x | 输入 | 源操作数。 |
返回值说明
输入数据的反正切值。
- 当
x为inf时,返回值为π/2。 - 当
x为-inf时,返回值为-π/2。 - 当
x为nan时,返回值为nan。
约束说明
无
调用示例
-
SIMT编程场景:
#include "simt_api/math_functions.h" __global__ __launch_bounds__(256) void compute_atanf(float *result, const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = atanf(x[idx]); } -
SIMD与SIMT混合编程场景:
#include "simt_api/math_functions.h" __simt_vf__ __launch_bounds__(256) inline void compute_atanf_vf(__gm__ float *result, __gm__ const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = atanf(x[idx]); } __global__ __vector__ void run_atanf(__gm__ float *result, __gm__ const float *x, uint32_t count) { asc_vf_call<compute_atanf_vf>(dim3(256), result, x, count); }
输入输出示例如下:
x:0.25, 0.75, 1.25, 1.75
result: 0.2449787 0.6435012 0.8960554 1.05165